## 1. Proxy service-tier trace

- [x] 1.1 Add an opt-in setting for safe service-tier trace logging
- [x] 1.2 Emit requested vs actual service-tier trace logs for streaming and compact Responses paths

## 2. Regression coverage

- [x] 2.1 Add unit tests for the trace log contract and configuration gate

## 3. Spec updates

- [x] 3.1 Add a Responses API compatibility requirement for safe service-tier trace logging
